==> magpy-raz-1.0.1.tar.gz: magpy-raz-1.0.1/README.md <==
# Magshimim GitLab Project Management
This package extracts project data from GitLab, and writes it to .csv files,
which can be used for monitoring and analysis (e.g., using Excel)

The data extracted by this package includes:
* `events` - (almost) every activity made, including opening and closing issues,
pushing to the repository, and more...

* `backlog` - a pool of issues, not associated with assignee or milestone.

* `sprints` - an advanced feature for close monitoring of sprint progress (see special requirements below)

### Installation
```
pip install magpy-raz
```

### Requirements
To use this package, you need to provide a [GitLab personal access token](https://docs.gitlab.com/ee/user/profile/personal_access_tokens.html) file, with `api` scope.

### Assumptions
* Gitlab projects belong to GitLab groups (not individual users)

* Each project has a defined `start_date` and `end_date`

* Output csv files will be created in the same folder as the main  program, and will have the same prefix, 
as the token file (e.g., `raz-events.csv`)

### Special Requirements for Sprint Tracking
To use the `sprints` feature, you need to implement the following in your 
GitLab projects:
*  Create a set of milestones, each with a start and due date, creating a 
  continuous timeline (i.e., the due date of sprint-1 is the day before the 
  start date of sprint-2)

*  Define a work-hours budget for the sprint, by including the following line 
  at the top of the milestone descrition: ` Budget: .... = __h`

*  Define work estimate for each issue, associated with the milestone, by 
  using the Gitlab `/estimate` command (see [GitLab Time Tracking](https://docs.gitlab.com/ee/user/project/time_tracking.html) for more details)

*  Use the standard `To Do`, `In Progress` and `Done` labels, to indicate 
  issue status.

### Example
```python
import magpy.general as mg
import magpy.hub as my
import magpy.hubs as mh

FILE_NAME_PREFIX = 'raz'
TOKEN_FILE = FILE_NAME_PREFIX + '-token.txt'

HUBS = [

    my.Hub(name='בית-שמש',
           group_id=5961818,
           start_date='2019-10-31',
           end_date='2020-04-01'),

    my.Hub(name='ירושלים',
           group_id=6231718,
           start_date='2019-10-29',
           end_date='2020-03-30')
]

# Connect to GitLab
gl = mg.MagGitlab(TOKEN_FILE)

# Get data for my hubs
hubs = mh.Hubs(gl=gl, hubs=HUBS, prefix=FILE_NAME_PREFIX)
hubs.write_csv_files()
```

### Author
[Raz Nitzan](mailto:raz.nitzan@gmail.com)

### License

Distributed under the [MIT License](LICENSE).

==> magpy-raz-1.0.4.tar.gz: magpy-raz-1.0.4/README.md <==
# Magshimim GitLab Project Management
This package extracts project data from GitLab, and writes it to .csv files,
which can be used for monitoring and analysis (e.g., using Excel)

The data extracted by this package includes:
* `events` - (almost) every activity made, including opening and closing issues,
pushing to the repository, and more...

* `backlog` - a pool of issues, not associated with assignee or milestone.

* `sprints` - an advanced feature for close monitoring of sprint progress (see special requirements below)

### Installation
```
pip install magpy-raz
```

### Requirements
To use this package, you need to provide a [GitLab personal access token](https://docs.gitlab.com/ee/user/profile/personal_access_tokens.html) file, with `api` scope.

### Assumptions
* Gitlab projects belong to GitLab groups (not individual users)

* Each project has a defined `start_date` and `end_date`

* Output csv files will be created in the same folder as the main  program, and will have the same prefix, 
as the token file (e.g., `raz-events.csv`)

### Special Requirements for Sprint Tracking
To use the `sprints` feature, you need to implement the following in your 
GitLab projects:
*  Create a set of milestones, each with a start and due date, creating a 
  continuous timeline (i.e., the due date of sprint-1 is the day before the 
  start date of sprint-2)

*  Define a work-hours budget for the sprint, by including the following line 
  at the top of the milestone descrition: ` Budget: .... = __h`

*  Define work estimate for each issue, associated with the milestone, by 
  using the Gitlab `/estimate` command (see [GitLab Time Tracking](https://docs.gitlab.com/ee/user/project/time_tracking.html) for more details)

*  Use the standard `To Do`, `In Progress` and `Done` labels, to indicate 
  issue status.

### Example
```python
import magpy.general as mg
import magpy.hub as my
import magpy.hubs as mh

TOKEN_FILE = 'token-raz.txt'

HUBS = [

    my.Hub(name='בית-שמש',
           group_id=5961818,
           start_date='2019-10-31',
           end_date='2020-04-01'),

    my.Hub(name='ירושלים',
           group_id=6231718,
           start_date='2019-10-29',
           end_date='2020-03-30')
]


def main():
    # Connect to GitLab
    gl = mg.MagGitlab(TOKEN_FILE)

    # Get data for my hubs
    hubs = mh.Hubs(gl=gl, hubs=HUBS)
    hubs.write_csv_files()


if __name__ == '__main__':
    main()
```

### Author
[Raz Nitzan](mailto:raz.nitzan@gmail.com)

### License

Distributed under the [MIT License](LICENSE).
